import { locationService } from '@grafana/runtime';

import { FormRequiredFields, Report, StepKey } from '../../types';
import { BASE_URL } from '../constants';
import { reportSteps } from '../index';

export const getNextStep = (currentStep?: StepKey) => {
  if (!currentStep) {
    return reportSteps[0];
  }
  const index = reportSteps.findIndex((step) => step.id === currentStep);

  // If the last step, return it
  if (index === reportSteps.length - 1) {
    return reportSteps[index];
  }

  return reportSteps[index + 1];
};

export const getPreviousStep = (currentStep?: StepKey) => {
  if (!currentStep || currentStep === reportSteps[0].id) {
    return;
  }

  const index = reportSteps.findIndex((step) => step.id === currentStep);

  return reportSteps[index - 1];
};

export const goToPreviousStep = (currentStep?: StepKey) => {
  const previous = getPreviousStep(currentStep);
  if (previous && previous.id !== currentStep) {
    locationService.push(`${BASE_URL}/${previous.id}`);
  }
};

const arrayFieldIsValid = (field: Report[keyof Report]) => {
  if (Array.isArray(field)) {
    return field?.length;
  }

  return false;
};

export const getMissingFields = (report: Report, id?: StepKey) => {
  const requiredFields: FormRequiredFields = [
    { step: StepKey.SelectDashboard, fields: ['dashboards'] },
    { step: StepKey.FormatReport, fields: ['formats'] },
    { step: StepKey.Share, fields: ['name', 'recipients'] },
  ];
  // Validate dashboards separately
  const hasMissingDashboard = !report.dashboards?.[0]?.dashboard?.name;
  if (!id) {
    // Validate all fields
    const requiredFieldNames = requiredFields.flatMap((field) => field.fields);
    return (
      requiredFieldNames?.some((field) => !report[field] || !arrayFieldIsValid(report[field])) || hasMissingDashboard
    );
  }
  if (id === StepKey.SelectDashboard) {
    return hasMissingDashboard;
  }

  const requiredFieldNames = requiredFields.find((field) => field.step === id)?.fields;
  return requiredFieldNames?.some((field) => !report[field] || !arrayFieldIsValid(report[field])); // Validate array fields also for display in stepper
};
